@@ -3,7 +3,7 @@ package SHARYANTO::Role::TermAttrs;
 use 5.010;
 use Moo::Role;
 
-our $VERSION = '0.68'; # VERSION
+our $VERSION = '0.69'; # VERSION
 
 my $dt_cache;
 sub detect_terminal {
@@ -93,6 +93,12 @@ has use_box_chars => (
             $self->{_term_attrs_debug_info}{use_box_chars_from} =
                 'BOX_CHARS env';
             return $ENV{BOX_CHARS};
+        } elsif (!$self->interactive) {
+            # most pager including 'less -R' does not support interpreting
+            # boxchar escape codes.
+            $self->{_term_attrs_debug_info}{use_box_chars_from} =
+                '(not) interactive';
+            return 0;
         } elsif (defined(my $bc = $self->detect_terminal->{box_chars})) {
             $self->{_term_attrs_debug_info}{use_box_chars_from} =
                 'detect_terminal';
@@ -185,7 +191,7 @@ SHARYANTO::Role::TermAttrs - Role for terminal-related attributes
 
 =head1 VERSION
 
-version 0.68
+version 0.69
 
 =head1 DESCRIPTION
 
@@ -278,7 +284,7 @@ Steven Haryanto <stevenharyanto@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Steven Haryanto.
+This software is copyright (c) 2014 by Steven Haryanto.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
